package main

import (
	"context"
	"fmt"
	"os"

	"github.com/openstack-k8s-operators/lib-common/modules/common/secret"
	metaV1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/client-go/kubernetes"
	coreV1Types "k8s.io/client-go/kubernetes/typed/core/v1"
	"k8s.io/client-go/tools/clientcmd"
)

var secretsClient coreV1Types.SecretInterface

func InitClients(namespace string) {
	kubeconfig := os.Getenv("HOME") + "/.kube/config"
	config, err := clientcmd.BuildConfigFromFlags("", kubeconfig)
	if err != nil {
		panic(err.Error())
	}
	clientset, err := kubernetes.NewForConfig(config)
	if err != nil {
		panic(err.Error())
	}
	secretsClient = clientset.CoreV1().Secrets(namespace)
}

func GetSecretHash(secretName string) string {
	sec, err := secretsClient.Get(context.TODO(), secretName, metaV1.GetOptions{})
	if err != nil {
		panic(err.Error())
	}
	secretHash, err := secret.Hash(sec)
	if err != nil {
		panic(err.Error())
	}

	return secretHash
}

func main() {
	namespace := os.Args[1]
	secretName := os.Args[2]
	InitClients(namespace)
	fmt.Println(GetSecretHash(secretName))
}
